# Monkey DAO PyMongo
Simple Data Access Object pattern implementation for [MongoDB](http://www.mongodb.org/) using [PyMongo API](https://api.mongodb.com/python/current/)


Installation guide
------------------

::

    pip install monkey-dao-pymongo

User guide
----------


# Monkey DAO

Simple Data Access Object pattern implementation

## Installation

````

    pip install monkey-dao-pymongo

````

# Documentation
For full documentation, visit [https://pymongo-dao.monkey-python.org](https://pymongo-dao.monkey-python.org)
